OC.L10N.register(
    "groupfolders",
    {
    "Deny" : "Refuzo",
    "Allow" : "Lejo",
    "Group" : "Grup",
    "Read" : "Lexoni",
    "Write" : "Shkruaj",
    "Create" : "Krijo",
    "Delete" : "Delete",
    "Share" : "Shpërndaje",
    "You" : "Ju",
    "Add group" : "Shto grupin",
    "Default" : "Paraprake",
    "Unlimited" : "E palimituar",
    "Delete \"{folderName}\"?" : "Fshini \"{folderName}\"?",
    "Folder name" : "Emri i dosjes",
    "Quota" : "Kuotë",
    "Previous" : "I mëparshëm",
    "Next" : "I ardhshëm",
    "User" : "Përdorues",
    "Unknown" : "I panjohur",
    "None" : "Asnjë",
    "{size} used" : "{size} e përdorur",
    "Unset" : "E pavendosur"
},
"nplurals=2; plural=(n != 1);");
